@@ -32,6 +32,7 @@ class Freebox(IPlugin):
 			languages=[self.configuration_lisa['lang']]).ugettext
 #
 	def switch(self, jsonInput):
+		rangs = [] 
 		bodies = ""
 		if jsonInput['outcome']['entities']['location']['body'] :
 			location = jsonInput['outcome']['entities']['location']['body']
@@ -59,12 +60,21 @@ class Freebox(IPlugin):
 				log.msg("BODIES  :  %s" % (bodies))
 				if rs['idx_sec'] <> "1":
 					log.msg("*************  'idx_sec'] <> 1 ****************")
-					# séparation de rs['idx'], nombre  
+					# séparation de rs['idx'], nombre   len(maliste)  
+					for rang in range(len(rs['idx'])
+						if rs['idx'][rang] == '|':
+							rangs.append(rang)
+							log.msg(" rang  :  %s" % (rangs)
+#>>> for rang in range(len(mot)):  # La variable rang parcourt les entiers de 0 au rang de la dernière lettre du mot.
+#...     if mot[rang] == 'i':
+#...         rangs.append(rang)    # Si la lettre du mot est 'i', on stocke le rang dans notre liste.
+#>>> rangs                         # On affiche le résultat.
+#[5, 7]
 					# search position '|' dans rs['idx']	
 					# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
 					for rx in range (1, int(rs['idx_sec'])):
 						log.msg(" rx  :  %s" % (rx)
-						log.msg("idx  :  %s" % (int(rs['idx_sec'])))
+						log.msg("idx_sec  :  %s" % (int(rs['idx_sec'])))
 						log.msg("idx  :  %s" % (rs['idx']))
 						resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 						log.msg("resp  :  %s" % (resp))
